sqltriples.Query.Query

Package sqltriples :: Module Query :: Class Query |
[show private | hide private]
[frames | no frames]

## Class Query

    AbstractQuery --+
                    |
                   Query

Known Subclasses:
  `Results`

    An abstract class providing support for lazy query evaluation.

Method Summary
| `__init__(self, store, functions)`
| `__getitem__(self, i)`
| `__len__(self)`
| `__repr__(self)`
| ``get_query`(self, index, constraints)` Return a query clause, associated values, and an updated table index (as a 3-tuple) for this object's query defined using the given table 'index' and the supplied, optional 'constraints' text.
| ``get_subquery`(self, parent_columns, parent_index, index, match_first, match_parent, match_child)` Make a subquery for this object using the given 'parent_columns' (indicating the columns which connect with this object's exposed columns), a 'parent_index' (indicating the table index used in the parent query, within which the returned query clause shall be employed), and the current table 'index'.

Class Variable Summary
Inherited from AbstractQuery
`list` | `table_columns` = `[('subject', 'subject_type', 0), ('predi...`

Method Details

### get_query(self, index, constraints=None)
    Return a query clause, associated values, and an updated table index (as
    a 3-tuple) for this object's query defined using the given table 'index'
    and the supplied, optional 'constraints' text.

### get_subquery(self, parent_columns, parent_index, index, match_first=0, match_parent=0, match_child=0)
    Make a subquery for this object using the given 'parent_columns'
    (indicating the columns which connect with this object's exposed
    columns), a 'parent_index' (indicating the table index used in the
    parent query, within which the returned query clause shall be employed),
    and the current table 'index'.

    Return a query clause, associated values, and an updated table index (as
    a 3-tuple).

Generated by Epydoc 2.1 on Fri Jan 12 00:04:34 2007 | http://epydoc.sf.net